# Changelog

## 0.1.0-alpha.1 (2025-05-10)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/vern-so/sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([e853a88](https://github.com/vern-so/sdk-python/commit/e853a88a119171ec4712a7c968e573c12bd0fff0))


### Chores

* configure new SDK language ([7ab27a6](https://github.com/vern-so/sdk-python/commit/7ab27a6b37eeec4cc46f720d376265266fd2c378))
* update SDK settings ([311bd67](https://github.com/vern-so/sdk-python/commit/311bd671409b6f51a20acd0d0917997aa51830fd))
* update SDK settings ([7e3ad06](https://github.com/vern-so/sdk-python/commit/7e3ad062dfb2429be0d312da663a04c48ad5df46))
